<?php

namespace jerryyan\notice\controller;

use jerryyan\notice\model\NoticeBroadcast;
use jerryyan\notice\service\NoticeService;
use jerryyan\staff\model\StaffDept;
use jerryyan\staff\model\StaffUser;
use think\admin\Controller;
use think\admin\helper\QueryHelper;

/**
 * 通知公告
 */
class Broadcast extends Controller
{
    /**
     * 通知公告
     * @auth true
     * @menu true
     * @return void
     */
    public function index()
    {
        $this->title = '通知公告';
        NoticeBroadcast::mQuery()->layTable(function () {
            $this->types = NoticeBroadcast::types();
        }, static function (QueryHelper $query) {
            $query->equal('type,status')->like('title,content');
        });
    }

    /**
     * 添加通知公告
     * @auth true
     * @return void
     */
    public function add()
    {
        NoticeBroadcast::mForm('form');
    }

    /**
     * 编辑通知公告
     * @auth true
     * @return void
     */
    public function edit()
    {
        NoticeBroadcast::mForm('form');
    }

    protected function _form_filter(array &$vo)
    {
        if ($this->request->isPost()) {
            if (empty($vo['to_depts'])) {
                if (empty($vo['id'])) {
                    $this->error('请选择通知对象！');
                }
                unset($vo['to_depts']);
            } else {
                $vo['to_depts'] = arr2str($vo['to_depts']);
            }
            if (empty($vo['to'])) {
                if (empty($vo['id'])) {
                    $this->error('请选择通知对象！');
                }
                unset($vo['to']);
            }
            if (empty($vo['id'])) {
                $vo['create_by'] = session('user.id');
            }
        } else {
            $this->depts = StaffDept::items();
            $this->types = NoticeBroadcast::types();
        }
    }

    protected function _form_result(bool $status, $vo)
    {
        if ($status) {
            if (empty($vo['id']) || !empty($vo['rebroadcast'])) {
                if (!empty($vo['to_all'])) {
                    $staffs = StaffUser::mk()->select();
                } else {
                    $depts = str2arr($vo['to_depts']);
                    $staffs = StaffUser::mk()->whereIn('dept_id', $depts)->select();
                }
                NoticeService::send_notice_to($vo['type'], $vo['content'], url('broadcast/view', ['id' => $vo['id']])->build(), $staffs->map(function($staff) {
                    return $staff['id'];
                }));
            }
        }
    }

    /**
     * 查看通知公告
     * @auth false
     * @return void
     */
    public function view()
    {
        $this->title = '查看通知公告';
        NoticeBroadcast::mForm('view');
    }

    protected function _view_form_filter(array &$vo) {
        $vo['creator'] = StaffUser::mk()->where(['id' => $vo['create_by']])->findOrEmpty();
    }

    /**
     * 删除通知公告
     * @auth true
     * @return void
     */
    public function remove()
    {
        NoticeBroadcast::mDelete();
    }
}